"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RouteTransferRequest = void 0;
const sdk_base_1 = require("@wormhole-foundation/sdk-base");
const sdk_definitions_1 = require("@wormhole-foundation/sdk-definitions");
const token_1 = require("./token");
class RouteTransferRequest {
    from;
    to;
    source;
    destination;
    fromChain;
    toChain;
    constructor(from, to, fromChain, toChain, source, destination) {
        this.from = from;
        this.fromChain = fromChain;
        this.to = to;
        this.toChain = toChain;
        this.source = source;
        this.destination = destination;
    }
    normalizeAmount(amount) {
        return (0, sdk_base_1.normalizeAmount)(amount, BigInt(this.source.decimals));
    }
    displayAmount(amount) {
        return (0, sdk_base_1.displayAmount)(amount, BigInt(this.source.decimals), BigInt(this.source.decimals));
    }
    displayQuote(quote) {
        let dq = {
            sourceToken: {
                token: quote.sourceToken.token,
                amount: (0, sdk_base_1.displayAmount)(quote.sourceToken.amount, BigInt(this.source.decimals), BigInt(this.source.decimals)),
            },
            destinationToken: {
                token: quote.destinationToken.token,
                amount: (0, sdk_base_1.displayAmount)(quote.destinationToken.amount, BigInt(this.destination.decimals), BigInt(this.destination.decimals)),
            },
        };
        if (quote.relayFee) {
            let amount = (0, sdk_definitions_1.isSameToken)(quote.relayFee.token, quote.sourceToken.token)
                ? (0, sdk_base_1.displayAmount)(quote.sourceToken.amount, BigInt(this.source.decimals), BigInt(this.source.decimals))
                : (0, sdk_base_1.displayAmount)(quote.destinationToken.amount, BigInt(this.destination.decimals), BigInt(this.destination.decimals));
            dq.relayFee = {
                token: quote.relayFee.token,
                amount,
            };
        }
        if (quote.destinationNativeGas) {
            dq.destinationNativeGas = (0, sdk_base_1.displayAmount)(quote.destinationNativeGas, BigInt(this.destination.decimals), BigInt(this.destination.decimals));
        }
        return dq;
    }
    static async create(wh, params, fromChain, toChain) {
        fromChain = fromChain ?? wh.getChain(params.from.chain);
        toChain = toChain ?? wh.getChain(params.to.chain);
        const sourceDetails = await (0, token_1.getTokenDetails)(fromChain, params.source);
        const destDetails = params.destination
            ? await (0, token_1.getTokenDetails)(toChain, params.destination)
            : undefined;
        const rtr = new RouteTransferRequest(params.from, params.to, fromChain, toChain, sourceDetails, destDetails);
        return rtr;
    }
}
exports.RouteTransferRequest = RouteTransferRequest;
//# sourceMappingURL=request.js.map