import { displayAmount, normalizeAmount } from "@wormhole-foundation/sdk-base";
import { isSameToken, } from "@wormhole-foundation/sdk-definitions";
import { getTokenDetails } from "./token";
export class RouteTransferRequest {
    from;
    to;
    source;
    destination;
    fromChain;
    toChain;
    constructor(from, to, fromChain, toChain, source, destination) {
        this.from = from;
        this.fromChain = fromChain;
        this.to = to;
        this.toChain = toChain;
        this.source = source;
        this.destination = destination;
    }
    normalizeAmount(amount) {
        return normalizeAmount(amount, BigInt(this.source.decimals));
    }
    displayAmount(amount) {
        return displayAmount(amount, BigInt(this.source.decimals), BigInt(this.source.decimals));
    }
    displayQuote(quote) {
        let dq = {
            sourceToken: {
                token: quote.sourceToken.token,
                amount: displayAmount(quote.sourceToken.amount, BigInt(this.source.decimals), BigInt(this.source.decimals)),
            },
            destinationToken: {
                token: quote.destinationToken.token,
                amount: displayAmount(quote.destinationToken.amount, BigInt(this.destination.decimals), BigInt(this.destination.decimals)),
            },
        };
        if (quote.relayFee) {
            let amount = isSameToken(quote.relayFee.token, quote.sourceToken.token)
                ? displayAmount(quote.sourceToken.amount, BigInt(this.source.decimals), BigInt(this.source.decimals))
                : displayAmount(quote.destinationToken.amount, BigInt(this.destination.decimals), BigInt(this.destination.decimals));
            dq.relayFee = {
                token: quote.relayFee.token,
                amount,
            };
        }
        if (quote.destinationNativeGas) {
            dq.destinationNativeGas = displayAmount(quote.destinationNativeGas, BigInt(this.destination.decimals), BigInt(this.destination.decimals));
        }
        return dq;
    }
    static async create(wh, params, fromChain, toChain) {
        fromChain = fromChain ?? wh.getChain(params.from.chain);
        toChain = toChain ?? wh.getChain(params.to.chain);
        const sourceDetails = await getTokenDetails(fromChain, params.source);
        const destDetails = params.destination
            ? await getTokenDetails(toChain, params.destination)
            : undefined;
        const rtr = new RouteTransferRequest(params.from, params.to, fromChain, toChain, sourceDetails, destDetails);
        return rtr;
    }
}
//# sourceMappingURL=request.js.map